'''
Created on May 02, 2015
import requests

@author: karpagm1
'''


    
class DictionaryEntry:
    
    def __init__(self):
        self.id = None
        self.uid = None
        self.externalUid = None
        self.createdDate = None
        self.modifiedDate = None
        self.name = None
        self.description = None
        self.entryType = None
        self.entryValue = None
        self.category = None
        self.parent = None
