'''
Created on May 03, 2015
import requests

@author: karpagm1
'''
from enum import Enum

    
class MasterDataEnum(Enum):
    FBI = 'FBI'    
    GLO = 'GLO'   
    NGM = 'NGM'   
    NGS = 'NGS'  
    UNI = 'UNI'
    
    
    
    
    
    
