'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


    
class DnaCase:
    
    def __init__(self):
        self.id = None
        self.caseName = None
        self.externalUid = None
        self.caseType = None
        self.uid = None
        self.externalUid = None
        self.description = None
        self.requester = None
        self.barcode = None
        self.caseType = None
        self.requestingOrganization = None
        self.createdDate = None
        self.modifiedDate = None
        self.casePriority = None