'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


    
class ContactViewObject:
    
    def __init__(self):
        self.id = None
        self.address = None
        self.city = None
        self.state = None
        self.zip = None
        self.country = None
        self.email = None
        self.workPhone = None
        self.homePhone = None
        self.mobilePhone = None
