'''
Created on May 03, 2015
import requests

@author: karpagm1
'''
from enum import Enum

    
class Relationship(Enum):
    child = 'Child'
    father = 'Father'
    mother = 'Mother'
    maternalGrandfather = 'Maternal Grandfather'
    maternalGrandmother = 'Maternal Grandmother'
    paternalGrandfather = 'Paternal Grandfather'
    paternalGrandmother = 'Paternal Grandmother'
    
    
    
    
    
