'''
Created on May 03, 2015
import requests

@author: karpagm1
'''
from enum import Enum

    
class EthinicityEnum(Enum):
    asian = 'Asian'
    seHispanic = 'SEHispanic'
    caucasian = 'Caucasian'
    africanAmerican = 'African American'
    swHispanic = 'SWHispanic'
    
    
    
    
    
